.. rst-class:: detail

PulseDigital
=======================

.. currentmodule:: compas_rrc

.. autoclass:: PulseDigital

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~PulseDigital.__init__
        ~PulseDigital.from_msg
    
    